package com.starbuds.server.game.sdkdev.request;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.starbuds.server.game.sdkdev.GameDevResponse;
import com.starbuds.server.game.sdkdev.param.AddOrderParam;
import com.starbuds.server.game.sdkdev.param.GetGameplayParam;
import com.starbuds.server.game.sdkdev.param.GetGamesParam;
import com.starbuds.server.game.sdkdev.param.GetPlayinfoParam;
import com.starbuds.server.game.sdkdev.response.GetGameplayResponse;
import com.starbuds.server.game.sdkdev.response.GetGamesResponse;
import com.starbuds.server.game.sdkdev.response.GetPlayinfoResponse;
import com.starbuds.server.game.sdkdev.response.data.GetGamesData;
import com.starbuds.server.game.sdkdev.response.data.GetPlayinfoData;
import com.starbuds.server.game.sdkdev.util.TestDevUtils;
import lombok.extern.slf4j.Slf4j;
import org.testng.Assert;
import org.testng.annotations.Test;

import java.util.List;

/**
 * 下单接口
 * 返点序列值 在 游戏列表那边返回了
 * 玩法、玩法值、名称 在 游戏玩法接口；玩法值=detail_order 这个值
 * 单价 、 倍数，是app上 用户填写
 *
 * @author aoe
 * @date 2020/9/24
 */
@Slf4j
public class AddOrderRequestTest {

    @Test
    public void addOrderRequestTest() {
        GetGamesData gamesData = getGameList().get(0);
        String gameId = gamesData.getGameId();
        // 返点序列值
        String series = gamesData.getSeries();

        GetPlayinfoData playInfo = getPlayInfoList(gameId).get(0);
        // 玩法id
        String playId = playInfo.getPlayId();
        // 玩法值
        Integer detailOrder = playInfo.getPlayDetails().get(0).getDetailOrder();
        // 玩法名称
        String playName = playInfo.getPlayName();
        // 当前投注期
        String curPeriod = getCurPeriod(gameId);

        // App
        // 倍数
        Integer bet = 10;
        // 单价
        Integer price = 1;
        // 玩法id^玩法值^投注模式(默认1)^总倍投数^返点序列值^单价^名称
        String detail = StrUtil.format("{}^{}^1^{}^{}^{}^{}",
                playId, detailOrder, bet, series, price, playName);

        AddOrderParam param = AddOrderParam.builder()
                .userid("1")
                .gameId(gameId)
                // 下单期号
                .byt1CurPno(curPeriod)
                // 倍数
                .byt1TtBet("" + bet)
                // 总额 = 单价 * 倍数
                .byt1TtMoney("" + 10)
                // 明细
                .btDtls(detail)
                .build();
        AddOrderRequest request = new AddOrderRequest();
        request.setParam(param);
        GameDevResponse res = TestDevUtils.getClient().execute(request);
        log.info("SDK结果");
        log.info(JSON.toJSONString(res));
        Assert.assertEquals(res.getCode(), "0000");
    }

    /**
     * 1. 返点序列值 在这里
     * 获取游戏列表
     *
     * @return
     */
    private List<GetGamesData> getGameList() {
        GetGamesParam param = GetGamesParam.builder()
                .userid("1")
                .build();
        GetGamesRequest request = new GetGamesRequest();
        request.setParam(param);
        GetGamesResponse res = TestDevUtils.getClient().execute(request);
        log.info("SDK结果");
        log.info(JSON.toJSONString(res));
        Assert.assertEquals(res.getCode(), "0000");

        return res.getData();
    }

    /**
     * 2. 玩法、玩法值=detail_order、名称;
     * 获取指定游戏玩法
     *
     * @param gameId
     * @return
     */
    private List<GetPlayinfoData> getPlayInfoList(String gameId) {
        GetPlayinfoParam param = GetPlayinfoParam.builder()
                .userid("1")
                .gameId(gameId)
                .build();
        GetPlayinfoRequest request = new GetPlayinfoRequest();
        request.setParam(param);
        GetPlayinfoResponse res = TestDevUtils.getClient().execute(request);
        log.info("SDK结果");
        log.info(JSON.toJSONString(res));
        Assert.assertEquals(res.getCode(), "0000");
        return res.getData();
    }

    /**
     * 3. 当前投注期
     *
     * @param gameId
     * @return
     */
    private String getCurPeriod(String gameId) {
        GetGameplayParam param = GetGameplayParam.builder()
                .userid("1")
                .gameId("JSFFC")
                .build();
        GetGameplayRequest request = new GetGameplayRequest();
        request.setParam(param);
        GetGameplayResponse res = TestDevUtils.getClient().execute(request);
        log.info("SDK结果");
        log.info(JSON.toJSONString(res));
        Assert.assertEquals(res.getCode(), "0000");
        return res.getData().getPeriodInfo().getRtAwdCurPeriod();
    }
}